====
API
====

Core Submodules
===============

tmtccmd module
---------------------

.. automodule:: tmtccmd
   :noindex:


.. toctree::
   :maxdepth: 2

   api/tmtccmd.core

Communication Submodule
========================

.. automodule:: tmtccmd.com
   :noindex:


.. toctree::
   :maxdepth: 2

   api/tmtccmd.com

Configuration Submodule
=========================

.. automodule:: tmtccmd.config
   :noindex:


.. toctree::
   :maxdepth: 2

   api/tmtccmd.config

CCSDS Submodules
===================

This currently contains the CFDP support.

.. toctree::
   :maxdepth: 2

   api/tmtccmd.cfdp
   api/tmtccmd.cfdp.handler

ECSS Submodules
=========================

.. automodule:: tmtccmd.pus
   :noindex:

.. toctree::
   :maxdepth: 2

   api/tmtccmd.pus
   api/tmtccmd.tc
   api/tmtccmd.tm

Other Submodules
=========================

.. toctree::
   :maxdepth: 2

   api/tmtccmd.util
   api/tmtccmd.logging
   api/tmtccmd.fsfw
